@@ -4,6 +4,8 @@ from .device import Device
 
 
 class SwitchDevice(Device):
+    """Class used for all switch devices"""
+
     def __init__(self, hub, device_data: DeviceData, device_config: DeviceConfig):
         super().__init__(hub, device_data, device_config)
 
@@ -13,6 +15,14 @@ class SwitchDevice(Device):
             )
 
     def turn_on_off(self, on: bool, send_local: bool = True) -> None:
+        """Change the state of the device.
+
+        Args:
+          on: new state of the device, True == on.
+          send_local: Use the ip_address set on the hub to talk to the device
+        """
+        if self.device_config.on_off_function is None:
+            return
         self.get_hub().turn_device_on_off(
             self.entity_id,
             on,
@@ -22,6 +32,13 @@ class SwitchDevice(Device):
         )
 
     def turn_on(self, send_local: bool = True) -> None:
+        """Turn on the device.
+
+        Args:
+          send_local: Use the ip_address set on the hub to talk to the device
+        """
+        if self.device_config.on_off_function is None:
+            return
         self.get_hub().turn_device_on_off(
             self.entity_id,
             True,
@@ -31,6 +48,13 @@ class SwitchDevice(Device):
         )
 
     def turn_off(self, send_local: bool = True) -> None:
+        """Turn off the device.
+
+        Args:
+          send_local: Use the ip_address set on the hub to talk to the device
+        """
+        if self.device_config.on_off_function is None:
+            return
         self.get_hub().turn_device_on_off(
             self.entity_id,
             False,
@@ -40,5 +64,8 @@ class SwitchDevice(Device):
         )
 
     def get_on_status(self) -> bool:
+        """Returns true if device is turned on"""
+        if self.device_config.on_off_function is None:
+            return False
         status = self.get_status()
         return status[self.device_config.on_off_function] == 1
